ci: enable examples

refs #3046

Change-Id: Iee4c0f8a003fb0651c21024a14697a80ace72119
diff --git a/.jenkins.d/10-build.sh b/.jenkins.d/10-build.sh
index 58d0b01..bb64511 100755
--- a/.jenkins.d/10-build.sh
+++ b/.jenkins.d/10-build.sh
@@ -26,11 +26,11 @@
 # Cleanup
 sudo ./waf -j1 --color=yes distclean
 
 # Configure/build shared library in debug mode without precompiled headers
 if has code-coverage $JOB_NAME; then
     COVERAGE="--with-coverage"
 fi
-./waf -j1 --color=yes configure --debug --enable-shared --disable-static --with-tests --without-pch $COVERAGE
+./waf -j1 --color=yes configure --debug --enable-shared --disable-static --with-tests --without-pch --with-examples $COVERAGE
 ./waf -j1 --color=yes build
 
 # (tests will be run against debug version)
@@ -26,11 +26,11 @@
 sudo ./waf -j1 --color=yes distclean
 
-# Configure/build shared library in debug mode without precompiled headers
+# Configure/build shared library in debug mode with examples without precompiled headers
 if has code-coverage $JOB_NAME; then
     COVERAGE="--with-coverage"